<?xml version="1.0" standalone="no" ?>
<!-- Alison Chaiken, 650-279-5600,alchaiken@gmail.com, sole author and originator -->
<!-- Released under GPL3 -->
<!-- Free beer *and* freedom! -->
<!-- This stylesheet is useful for transforming XML resume data into nicely formatted and valid XHTML Strict -->
<!-- Syntax: java ResumeParser ResumeIn.xml XHTMLresume.xsl ResumeOut.html -->

<!DOCTYPE stylesheet
     PUBLIC "-//W3C//DTD XSLT 1.0//EN"
     "http://www.w3.org/1999/11/xslt10.dtd"
     [
<!ENTITY space "<xsl:text> </xsl:text>">
<!ENTITY cr "<xsl:text>
</xsl:text>">
<!ENTITY FormattedName SYSTEM "FormattedName.xsl">
]>

	<!--
		Macros above from http://www.xml.com/pub/a/2001/12/05/whitespace.html.
		Note that indenting this file with Eclipse's Ctrl-I command moves 
		punctuation in this file onto the line following XSL commands.   
		The inserted linebreaks create unwanted whitespace in the HTML output.
	-->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:include href="ResumeSubTemplates.xsl"/>
<xsl:include href="ResumeProcessingVariables.xsl"/>

	<!--
		outputs XHTML resume from XML input
	-->
	<xsl:output method="xml" 
  doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" 
  doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" indent="yes"/>
	<xsl:strip-space elements="*" />
	<xsl:template match="resume">
		<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
			<head>
				<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
				<meta name="generator" content= "ResumeParser.java with XHTMLresume.xsl, see www.exerciseforthereader.org" />
				<link rel="stylesheet" href="Resume.css" type= "text/css" />
				<title>Resume for &FormattedName;
				</title>
			</head>
			<body>
				<h1>Resume for &FormattedName;</h1>
				<address>
					<!--  a linebreak between xsl instructions and punctuation creates unwanted whitespace in the XHTML output -->
					<xsl:apply-templates select="contact_info/street" />,
					<xsl:apply-templates select="contact_info/unit_number" />
					<br />
					<xsl:apply-templates select="contact_info/city"/>
					&space;
					<xsl:apply-templates select="contact_info/state"/>
					&space;
					<xsl:apply-templates select="contact_info/zip"/>
					<br />
					<a><xsl:attribute name="href">mailto:<xsl:value-of select="contact_info/email" /></xsl:attribute><xsl:value-of select="contact_info/email" />
					</a>
					<br />
					<xsl:if test="string-length(contact_info/phone/cell) > 0">
						<xsl:text>Mobile: </xsl:text>
						<xsl:apply-templates select="contact_info/phone/cell" />
						<br />
					</xsl:if>
					<xsl:if test="string-length(contact_info/phone/home) > 0">
						<xsl:text>Home: </xsl:text>
						<xsl:apply-templates select="contact_info/phone/home" />
						<br />
					</xsl:if>
					<xsl:if test="string-length(contact_info/phone/work) > 0">
						<xsl:text>Office: </xsl:text>
						<xsl:apply-templates select="contact_info/phone/work" />
						<br />
					</xsl:if>
					<xsl:if test="string-length(contact_info/url) > 0">
						<a>
							<xsl:attribute name="href">
							<xsl:value-of select="contact_info/url" />
						</xsl:attribute>
							<xsl:value-of select="contact_info/url" />
						</a>
						<br />
					</xsl:if>
					<xsl:if test="string-length(contact_info/IRC) > 0">
						<xsl:text>IRC: </xsl:text>
						<xsl:apply-templates select="contact_info/IRC" />
						<br />
					</xsl:if>
					<xsl:if test="string-length(contact_info/Twitter) > 0">
						<xsl:text>Twitter: </xsl:text>
						<xsl:apply-templates select="contact_info/Twitter" />
						<br />
					</xsl:if>
				</address>
				
					<!--  Tags like <h1>, <h2> cannot be inside paragraphs, spans or divs, while mark-up like <em> or <b> must be. -->	
				<h4>Expertise:</h4>
				<div>
				<xsl:value-of select="$mungedExpAreaList"/>
				</div>
				
					
					<h4>Skills:</h4>
					<div>
					<xsl:value-of select="$mungedSkillList"/>
					</div>

				<h2>
					Employment:
					<br />
				</h2>
				<xsl:for-each select="employment/employer">
					<h3>
						<xsl:value-of select="tenure_start" />-<xsl:value-of select="tenure_end" />:
						<xsl:value-of select="emp_title" /> &space;
						at &space;
						<xsl:value-of select="emp_name" />
						<br />
					</h3>
					<xsl:if test="string-length(project) > 0">
							<h4>Projects:</h4>
							<div>
							<xsl:for-each select="project[not(position()=last())]">
				&space;
								<!--
									a carriage return between the value-of element and the comma
									puts a space in the output
								-->
								<xsl:if test="string-length(@project_uri) > 0">
									<a><xsl:attribute name="href"><xsl:value-of select="@project_uri" /></xsl:attribute><xsl:value-of select="." />;
									</a>
									</xsl:if>
									<xsl:if test="string-length(@project_uri) = 0">
										<xsl:value-of select="." />;			
									</xsl:if>
							</xsl:for-each>
							<xsl:for-each select="project[(position()=last())]">
				&space;
								<!--
									a carriage return between the value-of element and the period
									puts a space in the output
								-->
								<xsl:if test="string-length(@project_uri) > 0">
									<a>
										<xsl:attribute name="href">
																		<xsl:value-of select="@project_uri" />
																	</xsl:attribute>
										<xsl:value-of select="." />.
									</a>
									</xsl:if>
									<xsl:if test="string-length(@project_uri) = 0">
										<xsl:value-of select="." />.			
									</xsl:if>
							</xsl:for-each>
							</div>
					</xsl:if>
					<xsl:if test="string-length(accomplishment) > 0">
						
							<p></p>
							<h4>Accomplishments:</h4>
							<div>
							<xsl:for-each select="accomplishment[not(position()=last())]">
				&space;
								<!--
									a carriage return between the value-of element and the comma
									puts a space in the output
								-->
								<xsl:if test="string-length(@accomplishment_uri) > 0">
									<a><xsl:attribute name="href"><xsl:value-of select="@accomplishment_uri" /></xsl:attribute><xsl:value-of select="." />;
									</a>
									</xsl:if>
									<xsl:if test="string-length(@accomplishment_uri) = 0">
										<xsl:value-of select="." />;			
									</xsl:if>
							</xsl:for-each>
							<xsl:for-each select="accomplishment[(position()=last())]">
				&space;
								<!--
									a carriage return between the value-of element and the period
									puts a space in the output
								-->
								<xsl:if test="string-length(@accomplishment_uri) > 0">
									<a>
										<xsl:attribute name="href">
																		<xsl:value-of select="@accomplishment_uri" />
																	</xsl:attribute>
										<xsl:value-of select="." />.
									</a>
									</xsl:if>
									<xsl:if test="string-length(@accomplishment_uri) = 0">
										<xsl:value-of select="." />.			
									</xsl:if>
							</xsl:for-each>
							</div>
					</xsl:if>
					
					<xsl:if test="string-length(publication) > 0">
							<p></p>
							<h4>Major Publications:</h4>
							
							<xsl:for-each select="publication">
							<!--  create hyperlink if there's a URI; if not, just create the element -->
								<div>
								<xsl:if test="string-length(@publication_uri) > 0">
									&quot;<a>
										<xsl:attribute name="href">
																		<xsl:value-of select="@publication_uri" />
																	</xsl:attribute>
										<xsl:value-of select="pub_name" />
									</a>
									<xsl:text>,"</xsl:text>&space;<xsl:value-of select="pub_journal" />.
									</xsl:if>
									<xsl:if test="string-length(@publication_uri) = 0">
										&quot;<xsl:value-of select="pub_name" /><xsl:text>,"</xsl:text>&space;<xsl:value-of select="pub_journal"/>.			
									</xsl:if>
								</div>
								
							</xsl:for-each>
							
					</xsl:if>
					<xsl:if test="string-length(patent) > 0">
							<p></p>
							<h4>Major Patents:</h4>
							<xsl:for-each select="patent">
							<!--  create hyperlink if there's a URI; if not, just create the element -->
								<div><xsl:if test="string-length(@patent_uri) > 0">
									&quot;<a>
										<xsl:attribute name="href">
																		<xsl:value-of select="@patent_uri" />
																	</xsl:attribute>
										<xsl:value-of select="patent_name" />
									</a><xsl:text>,"</xsl:text>&space; <xsl:value-of select="patent_number" />.
									</xsl:if>
									<xsl:if test="string-length(@patent_uri) = 0">
										&quot;<xsl:value-of select="patent_name" /><xsl:text>,"</xsl:text>&space; <xsl:value-of select="patent_number" />.			
									</xsl:if>
								</div>
								
							</xsl:for-each>
							
					</xsl:if>
				</xsl:for-each>
				<h2>
					Education:
				</h2>
				<xsl:for-each select="education/institution">
					<p>
						<span>
							<xsl:value-of select="school_start" />-<xsl:value-of select="school_end" />:
							<xsl:if test="string-length(degree) > 0">
								<xsl:value-of select="degree" />, &space;
							</xsl:if>
							<xsl:if test="string-length(school_name) > 0">
								<xsl:apply-templates select="school_name"/>
							</xsl:if>
							<xsl:if test="string-length(concentration) > 0">, &space;
								<xsl:value-of select="concentration" />.
							</xsl:if>
						</span>
						<xsl:if test="count(course) > 1"> courses
							<xsl:for-each select="course[not(position()=last())]">
				&space;
								<!--
									a carriage return between the value-of element and the comma
									puts a space in the output
								-->
								&quot;<xsl:if test="string-length(@course_uri) > 0">
									<a>
										<xsl:attribute name="href">
																		<xsl:value-of select="@course_uri" />
																	</xsl:attribute>
										<xsl:value-of select="." />
									</a>
									</xsl:if>
									<xsl:if test="string-length(@course_uri) = 0">
										<xsl:value-of select="." />			
									</xsl:if><xsl:text>,"</xsl:text>
							</xsl:for-each>
							<xsl:for-each select="course[(position()=last())]">
				&space;
								<!--
									a carriage return between the value-of element and the period
									puts a space in the output
								-->
								&quot;<xsl:if test="string-length(@course_uri) > 0">
									<a>
										<xsl:attribute name="href">
																		<xsl:value-of select="@course_uri" />
																	</xsl:attribute>
										<xsl:value-of select="." />
									</a>
									</xsl:if>
									<xsl:if test="string-length(@course_uri) = 0">
										<xsl:value-of select="." />			
									</xsl:if><xsl:text>."</xsl:text>
							</xsl:for-each>
						</xsl:if>
						<xsl:if test="(count(course) = 1)">
							<xsl:apply-templates select="course"/>.
						</xsl:if>
						</p>
				</xsl:for-each>	
				
				<xsl:if test="count(professional_activities/activity) > 0">	
					<h2>Professional Activities:</h2>
					<ul>
						<xsl:for-each select="professional_activities/activity">
							<xsl:if test="(string-length(act_start) > 0) and (string-length(act_end)>0)">
								<li><xsl:value-of select="act_start"/>-<xsl:value-of select="act_end"/>: &space; <xsl:apply-templates select="act_name"/>.</li>
							</xsl:if>
							<xsl:if test="(string-length(act_start) = 0) or (string-length(act_end)=0)">
								<li><xsl:apply-templates select="act_name"/>.</li>
							</xsl:if>
						</xsl:for-each>
					</ul>
				</xsl:if>
				
				<xsl:if test="count(personal/persitem) > 0">	
				<h2>Personal:</h2>
				<p>
				<xsl:for-each select="personal/persitem[not(position()=last())]">
							&space;
				<!--
					a carriage return between the value-of element and the comma puts a
					space in the output
				-->
				<xsl:if test="string-length(@pers_uri) > 0">
					<a>
						<xsl:attribute name="href"><xsl:value-of select="@pers_uri" /></xsl:attribute>
						<xsl:value-of select="." />
					</a>
				</xsl:if>
				<xsl:if test="string-length(@pers_uri) = 0">
					<xsl:value-of select="." />
				</xsl:if>,
			</xsl:for-each>
				<xsl:for-each select="personal/persitem[(position()=last())]">
							&space;
					<!--
						a carriage return between the value-of element and the period puts a
						space in the output
					-->
					<xsl:if test="string-length(@pers_uri) > 0">
						<a>
							<xsl:attribute name="href"><xsl:value-of select="@pers_uri" /></xsl:attribute>
							<xsl:value-of select="." />
						</a>
					</xsl:if>
					<xsl:if test="string-length(@pers_uri) = 0">
						<xsl:value-of select="." />
					</xsl:if>.
				</xsl:for-each>
				</p>
				</xsl:if>
				<p><a href="http://validator.w3.org/check/referer">
					<img src="./icons1/valid-xhtml10.png" alt="Valid XHTML 1.0!"
						height="31" width="88" />
				</a>
			
				<a href="http://jigsaw.w3.org/css-validator/check/referer">
					<img src="./icons1/valid-css.png" alt="Valid CSS!" height="31"
						width="88" />
				</a></p>
			</body>
		</html>
	</xsl:template>   <!--  End of root template -->

</xsl:stylesheet>
